@@ -3,9 +3,10 @@ from leanai.model.layers.batch_normalization import BatchNormalization
 from leanai.model.layers.convolution import Conv1D, Conv2D
 from leanai.model.layers.dense import Dense
 from leanai.model.layers.detection import DetectionHead, GridAnchorGenerator
+from leanai.model.layers.dropout import Dropout
 from leanai.model.layers.flatten import Flatten
 from leanai.model.layers.image_conversion import ImageConversion
-from leanai.model.layers.pooling import GlobalAveragePooling1D, GlobalAveragePooling2D, MaxPooling1D, MaxPooling2D
+from leanai.model.layers.pooling import GlobalAveragePooling1D, GlobalAveragePooling2D, MaxPooling1D, MaxPooling2D, AdaptiveAvgPool2D
 from leanai.model.layers.reshape import Reshape
 from leanai.model.layers.roi_ops import RoiAlign, RoiPool, BoxToRoi
 from leanai.model.layers.selection import TopKIndices, Gather, GatherTopKIndices
